NCI Thesaurus

skip navigation links

Version:23.09d (Release date:2023-09-25)

Contains Exact Match Begins With
Name Code Property Relationship
| Advanced Search

| EVS Home NCI Metathesaurus Browser NCI Thesaurus Browser NCI Thesaurus Exporter EVS Explore NCI Term Browser NCI Terminology Resources Term Suggestion

Welcome

NCI Thesaurus (NCIt) provides reference terminology for many NCI and other systems. It covers vocabulary for clinical care, translational and basic research, and public information and administrative activities. NCIt features: Stable, unique codes for biomedical concepts; Preferred terms, synonyms, research codes, external source codes, and other information; Over 100,000 textual definitions; Links to NCI Metathesaurus and other information sources; Over 500,000 cross-links between concepts, providing formal logic-based definition of many concepts; Extensive content integrated from NCI and other partners, much available as separate NCIt subsets Updated frequently by a team of subject matter experts. NCIt is a widely recognized standard for biomedical coding and reference, used by a broad variety of public and private partners both nationally and internationally including the Clinical Data Interchange Standards Consortium Terminology (CDISC), the U.S. Food and Drug Administration (FDA), the Federal Medication Terminologies (FMT), and the National Council for Prescription Drug Programs (NCPDP). Suggest a term: Thesaurus Term Suggestion Form Source Home Page: https://ncit.nci.nih.gov Download: http://evs.nci.nih.gov/ftp1/NCI_Thesaurus More Information: https://wiki.nci.nih.gov/x/lAVy |
|  |  | NCI Enterprise Vocabulary Services: Terminology resources and services for NCI and the biomedical community.
|  |  | NCI Metathesaurus: Comprehensive database of 6,700,000 terms from over 85 terminologies.
|  |  | NCI Term Browser: NCI and other terminologies in an integrated environment.
|  |  | NCI Thesaurus Report Exporter: A tool to customize exports of data from NCI Thesaurus (NCIt).
|  |  | EVS Explore: EVS next generation terminology browser.
|  |  | NCI Terminology Resources: More information on NCI dictionaries and resources.